Learn R Programming

munsellinterpol (version 3.5-1)

LabToMunsell: Convert CIE Lab coordinates to Munsell HVC

Description

LabToMunsell Converts CIE Lab coordinates to Munsell HVC, by interpolating over the extrapolated Munsell renotation data

Usage

LabToMunsell( Lab, white='D65', adapt='Bradford', ... )

Value

An Nx3 matrix with the Munsell HVC coordinates in each row. The rownames are set to those of Lab.

Arguments

Lab

CIE Lab coordinates. An Nx3 matrix, or a vector that can be converted to such a matrix. Each row of the matrix has Lab.

white

XYZ for the source white - a numeric 3-vector with scaling irrelevant. white can also be a numeric 2-vector; which is interpreted as xy chromaticity and converted to XYZ with Y=100. white can also be the name of any standard illuminant recognized by spacesXYZ::standardXYZ() which is scaled so that Y=100. The default 'D65' is converted to c(95.047,100,108.883).

adapt

method for chromatic adaptation, see spacesXYZ::CAT() for valid values. Also see Details.

...

other parameters passed to XYZtoMunsell()

Condition Signaling

For an overview see: Appendix E - Logging and Condition Signaling in the User Guide.

In case of an ERROR event, a condition is signaled with one of these additional S3 classes: "invalid_argument" or "package_unavailable", whichever is appropriate. The invalid argument, or the name of the unavailable package, is added to the condition object.

Author

Jose Gama and Glenn Davis

Details

The conversion is done in these steps.

  • Lab → XYZ using spacesXYZ::XYZfromLab() with the given white.

  • XYZ → HVC using XYZtoMunsell(). Before the Munsell conversion, XYZ is internally adapted from the given white to Illuminant C using the given adapt method.

References

Paul Centore 2014 The Munsell and Kubelka-Munk Toolbox https://www.munsellcolorscienceforpainters.com/MunsellAndKubelkaMunkToolbox/MunsellAndKubelkaMunkToolbox.html

See Also

MunsellToLab(), XYZtoMunsell(), spacesXYZ::standardXYZ(), spacesXYZ::CAT(), spacesXYZ::XYZfromLab()

Examples

Run this code
LabToMunsell( c(74.613450, -20.4, 10.1,    80, 0, 0) )
##                      H        V       C
##  3.1G 7.4/3.6 43.13641 7.379685 3.62976
##  N 7.9/        0.00000 7.945314 0.00000

Run the code above in your browser using DataLab