An Nx3 matrix with the Munsell HVC coordinates in each row.
The rownames are set to those of Luv.
Arguments
Luv
CIE Luv coordinates An Nx3 matrix, or a vector that can be converted to such a matrix. Each row of the matrix has Luv.
white
XYZ for the source white - a numeric 3-vector with scaling irrelevant.
white can also be a numeric 2-vector; which is interpreted as xy chromaticity and converted to XYZ with Y=100.
white can also be the name of any standard illuminant recognized by
spacesXYZ::standardXYZ() which is scaled so that Y=100.
The default 'D65' is converted to c(95.047,100,108.883).
In case of an ERROR event, a condition is signaled with one of these additional
S3 classes: "invalid_argument" or "package_unavailable",
whichever is appropriate.
The invalid argument, or the name of the unavailable package, is added to the condition object.
Author
Jose Gama and Glenn Davis
Details
The conversion is done in these steps:
Luv → XYZ using spacesXYZ::XYZfromLuv() with the given white.
XYZ → HVC using XYZtoMunsell().
Before the conversion to HVC, XYZ is internally adapted from the given white to Illuminant C using
the given chromatic adaptation method, see spacesXYZ::CAT().
References
Paul Centore 2014
The Munsell and Kubelka-Munk Toolbox
https://www.munsellcolorscienceforpainters.com/MunsellAndKubelkaMunkToolbox/MunsellAndKubelkaMunkToolbox.html