MunsellBooks: The Munsell Chips present in Specialized and Full Munsell...

MunsellBooksR Documentation

The Munsell Chips present in Specialized and Full Munsell Books

Description

In addition to the standard glossy and matte books, Munsell publishes books for specialized fields. For 5 of these specialized books, we use a paper by Ferguson, which gives the chip contents of books for these fields: soil, rocks, beads, and plants. It also includes newstudent Color Set, see References.
For the full glossy and matte books, see Source.

Format

A data.frame with 1753 rows and these columns:

HVC a matrix with 3 columns: Hue, Value, and Chroma. For the chromatic chips, Hue is a positive multiple of 2.5, except for 3 chips in the bead book which are odd multiples of 1.25. For the achromatic neutral chips, Hue is really undefined, but here it is set to 0. Value is always a positive multiple of 0.25, and between 0.5 and 9.5. Chroma is a non-negative integer between 0 and 16, except 13 and 15 are omitted.
FergusonName the color name of the chip, as assigned by Ferguson. If a chip does not appear in one of the 5 specialized books, it is set to NA.
bead a logical value. If TRUE then the chip appears in the bead book
newstudent a logical value. If TRUE then the chip appears in the newstudent book
plant a logical value. If TRUE then the chip appears in the plant book
rock a logical value. If TRUE then the chip appears in the rock book
soil a logical value. If TRUE then the chip appears in the soil book
glossy a logical value. If TRUE then the chip appears in the glossy book
matte a logical value. If TRUE then the chip appears in the matte book

The rows are sorted first by Hue, then Value, and then Chroma, all in increasing order. Thus the achromatic neutral chips come first, followed by the chromatics.

Details

The chip counts in the 7 books are:

Book | Neutral Chips | Chromatic Chips | Total Chips |
Soil 10 427 437
Rock 9 106 115
Bead 5 171 176
Plant 0 332 332
New Munsell Student 8 238 246
Glossy 37 1485 1522
Matte 32 1269 1301

The union of all 7 books has 1753 chips. There are only 3 inclusions among the books: Rock \subset Glossy, Plant \subset Glossy, and New_Munsell_Student \subset Matte.

Acknowledgements

The conversion of the 5 specialized books data to ./inst/extdata/Supplement1_3.6.2024.csv was done by Willie Ondricek, who provided all the motivation for this function. He also kindly provided photographs of the soil book, and much other material.

The data on the first 5 books of chips in the following table was converted from the file
yjfa_a_11710256_sm0001.docx, which is Online Supplement #1 from Ferguson.

For the Matte book, the 1269 chromatic chips are taken from:
https://sites.uef.fi/spectral/databases-software/munsell-colors-matt-spectrofotometer-measured/.
For the Glossy book, the 1485 chromatic chips are taken from:
https://www.munsellcolorscienceforpainters.com/MunsellResources/MunsellResources.html
/SpectralReflectancesOf2007MunsellBookOfColorGlossy.txt.

References

Ferguson, Jonathan. Munsell notations and color names: Recommendations for archaeological practice. Journal of Field Archaeology. 39:4. 327-335. (2014). Online Supplement #1.

Long, J. T. The New Munsell Student Color Set. New York: Fairchild Books. 2011.

Munsell Color. Munsell Soil-Color Charts. Grand Rapids, MI: 2009.

Munsell Color. Geological Rock-Color Chart. GrandRapids, MI: 2009.

Munsell Color. Munsell Bead Color Book. Grand Rapids, MI: 2012.

Munsell Color. Munsell Color Charts for Plant Tissues. New Windsor, NY: 1977.

See Also

roundHVC()

Examples

str(MunsellBooks)

## 'data.frame':   1753 obs. of  9 variables:
## $ HVC         : num [1:1753, 1:3] 0 0 0 0 0 0 0 0 0 0 ...
##  ..- attr(*, "dimnames")=List of 2
##  .. ..$ : NULL
##  .. ..$ : chr [1:3] "H" "V" "C"
## $ FergusonName: chr  NA NA "Black" NA ...
## $ bead        : logi  FALSE FALSE TRUE FALSE FALSE FALSE ...
## $ newstudent  : logi  FALSE FALSE FALSE FALSE FALSE FALSE ...
## $ plant       : logi  FALSE FALSE FALSE FALSE FALSE FALSE ...
## $ rock        : logi  FALSE FALSE TRUE FALSE FALSE FALSE ...
## $ soil        : logi  FALSE FALSE FALSE FALSE FALSE FALSE ...
## $ glossy      : logi  TRUE TRUE TRUE TRUE TRUE TRUE ...
## $ matte       : logi  FALSE FALSE FALSE FALSE FALSE TRUE ...

munsellinterpol documentation built on March 13, 2026, 1:06 a.m.