powered by
MunsellToLuv Converts a Munsell specification into CIE Luv coordinates, by interpolating over the extrapolated Munsell renotation data
MunsellToLuv
MunsellToLuv(MunsellSpec, InterpolateByLuminanceFactor=TRUE)
standard Munsell specification or a Munsell vector in ColorLab format
logical, TRUE = interpolation by luminance factor
CIE Lab coordinates of MunsellSpec illuminated by Illuminant C
status of the operation
Paul Centore 2014 The Munsell and Kubelka-Munk Toolbox http://www.99main.com/~centore/MunsellAndKubelkaMunkToolbox/MunsellAndKubelkaMunkToolbox.html
# NOT RUN { MunsellToLuv('7.6P 8.9/2.2') # }
Run the code above in your browser using DataLab