## make expected XYZ for a Perfect Reflecting Diffuser, under Illuminant D65
white.D65 = 100 * as.numeric( spacesXYZ::standardXYZ( 'D65' ) )
white.D65
## [1] 95.047 100.000 108.883
## convert Munsell 'N 10/' - the Perfect Reflecting Difuser - to XYZ
MunsellToXYZ( "N 10/" )
## X Y Z
## N 10/ 98.03984 100 118.1157
## this is the white point of Illuminant C, and not equal to white.D65
## Redo and supply the true white point.
MunsellToXYZ( "N 10/", white=white.D65 )
## X Y Z
## N 10/ 95.047 100 108.883
##
## now we have a match
MunsellToXYZ('7.6P 8.9/2.2')
## X Y Z
## 7.6P 8.9/2.2 75.6055 74.61345 92.92308
Run the code above in your browser using DataLab