| plotLociHC | R Documentation |
Plot Curves of Constant Munsell Hue and Chroma
plotLociHC( value=5, hue=seq(2.5,100,by=2.5), chroma='auto', coords='xy',
main="Value %g/", est=FALSE, ... )
value |
a Munsell value for which the plot is created.
It must be in the interval (0,10].
|
hue |
a numeric vector for which curves of contant Hue are plotted.
Each of these radial curves starts at Munsell Chroma = |
chroma |
a numeric vector for which ovoids of constant Chroma are plotted.
Each of these ovoids is closed; i.e. goes full circle from Hue=0 to Hue=100.
If |
coords |
either |
main |
a string used to set the main title of the plot.
The optional placeholder |
est |
if |
... |
other arguments passed to the function |
The plot limits (xlim and ylim) are set to include
all points where the Hue radials intersect the Chroma ovoids,
plus the white point.
If value is one of {0.2,0.4,0.6,0.8,1,2,3,4,5,6,7,8,9,10}
then published points from real.dat
are plotted with filled black points (real points),
and extrapolated points from all.dat are drawn with open circles (unreal points).
TRUE for success and FALSE for failure.
For an overview see: Appendix E - Logging and Condition Signaling in the User Guide.
In case of an ERROR or FATAL event, an error condition is signaled with one of these additional
S3 classes: "invalid_argument" or "package_unavailable" or "internal_error",
whichever is appropriate.
The invalid argument, or the name of the unavailable package, is added to the condition object.
In case of an WARN event, a warning condition is signaled with the additional
S3 class "incomplete".
The condition object also has the the subvector of Value's that could not be plotted
as item invalid, and their indexes as item indexes.
The option hcinterp='bicubic' makes fairly smooth ovoids,
and hcinterp='bilinear' makes 40-sided polygons (when coords='xy').
Compare with the plots in
Newhall et. al. (1943),
Judd, et. al. (1956),
and Judd, et. al. (1975) p. 263.
Glenn Davis
Newhall, Sidney M., Dorothy Nickerson, Deane B. Judd. Final Report of the O.S.A. Subcommitte on the Spacing of the Munsell Colors. Journal of the Optical Society of America. Vol. 33. No. 7. pp. 385-418. July 1943.
Judd, Deane B. and GC<nther Wyszecki. Extension of the Munsell Renotation System to Very Dark Colors. Journal of the Optical Society of America. Vol. 46. No. 4. pp. 281-284. April 1956.
Judd, Deane B. and GC<nther Wyszecki. Color in Business, Science, and Industry. 3rd edition. John Wiley & Sons. 1975.
MunsellToxyY(),
HueNumberFromString()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.