| HVCfromMunsellName | R Documentation |
Convert Munsell Notation to numerical Munsell HVC
HVCfromMunsellName( MunsellName )
HueNumberFromString( HueString )
MunsellHVC( MunsellName )
MunsellName |
a character vector of length N > 0,
where each string should be a valid Munsell notation, e.g.
|
HueString |
a character vector of length N > 0,
where each string should be the initial hue part of a Munsell notation,
e.g. '4.5GY', '2.5R', '10.3B', etc.
Whitespace is optional and ignored.
Neutrals, denoted by |
HVCfromMunsellName()
returns a numeric Nx3 matrix with HVC in the rows.
For neutral colors, both H and C are set to 0.
If a string cannot be parsed, the entire row is set to NAs.
The rownames are set to MunsellName.
HueNumberFromString() returns the hue number H.
If the string cannot be parsed, the output is set to NA.
For the 2 previous functions the Hue Number is wrapped to (0,100], except when Chroma==0 and then Hue=0.
MunsellHVC()
returns a character Nx3 matrix with HVC in the rows.
It is deprecated and and is here for backward compatibility with older versions of the package.
For neutral colors, H is set to 'N' and C is set to '0'.
For an overview see: Appendix E - Logging and Condition Signaling in the User Guide.
In case of an ERROR event, an error condition is signaled with the additional
S3 class "invalid_argument".
The invalid argument is added to the condition object.
In the case that not all HVC rows, or Hue numbers, could be computed,
because some of the strings are invalid,
a warning condition is signaled with the additional S3 class "incomplete".
The condition object also has the subvector of invalid strings as item invalid,
and their indexes as item indexes.
Ever since the Munsell Book of Color (1929), the Munsell hue circle has been divided into 5 principal hues and 5 intermediate hues, to define a total of 10 arcs. Each of these hues has been assigned a 10-point scale, with 5 at the midpoint of the arc. Moreover, the hue "origin" has been at '10RP'. So a 100-point scale (with no letters) for the entire hue circle is obvious and trivial to construct, but I have been unable to determine the first explicit mention of such a scale. The earliest I have have found is from Nimeroff (1968), Figures 20 and 21 on page 27.
There is a reference to ASTM D 1535 in the References of Nimeroff,
but it is not dated, and the 2 figures are not attributed to it.
There was an ASTM D 1535 in 1968 but I have not been able to locate it;
it is possible that the 100-point scale first appeared in ASTM D-1535 (1968),
or even earlier in ASTM D 1525-58T (1958).
Interestingly, in the Atlas of the Munsell Color System (1915) there were only
5 principal hues (with no intermediate hues) and each of the 5 arcs was assigned a 10-point scale.
If the entire hue circle of 1915 were assigned a scale, it would have been a 50-point scale.
Glenn Davis
Nimeroff, I. Colorimetry. National Bureau of Standards Monograph 104. January 1968. 35 cents.
ASTM D 1535-80. Standard Practice for Specifying Color by the Munsell System. 1980.
Munsell Book of Color: defining, explaining, and illustrating the fundamental characteristics of color. Munsell Color Co. 1929.
Atlas of the Munsell Color System. Malden, Mass., Wadsworth, Howland & Co., inc., Printers. 1915.
MunsellNameFromHVC(),
HueStringFromNumber()
HVCfromMunsellName( c( "4.2P 2.9/3.8", "N 2.3/", "N 8.9/0" ) )
## H V C
## 4.2P 2.9/3.8 84.2 2.9 3.8
## N 2.3/ 0.0 2.3 0.0
## N 8.9/0 0.0 8.9 0.0
HueNumberFromString( c('4B','4.6GY','10RP','N') )
## [1] 64.0 34.6 100.0 NA
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.