HVCfromMunsellName()
returns a numeric Nx3 matrix with HVC in the rows.
For neutral colors, both H and C are set to 0.
If a string cannot be parsed, the entire row is set to NAs.
The rownames are set to MunsellName.
HueNumberFromString() returns the hue number H.
If the string cannot be parsed, the output is set to NA.
For the 2 previous functions the Hue Number is wrapped to (0,100],
except when Chroma==0 and then Hue=0.
MunsellHVC()
returns a character Nx3 matrix with HVC in the rows.
It is deprecated and and is here for backward compatibility with older versions of the package.
For neutral colors, H is set to 'N' and C is set to '0'.